<?php

namespace App\Http\Controllers\Auth;

use Illuminate\Http\Request;

use App\Http\Controllers\Controller;
use App\Providers\RouteServiceProvider;
use App\User;
use Illuminate\Foundation\Auth\RegistersUsers;
use Illuminate\Support\Facades\Hash;
use Illuminate\Support\Facades\Validator;

use Spatie\Permission\Models\Role;
use Spatie\Permission\Models\Permission;

class RegisterController extends Controller
{
    /*
    |--------------------------------------------------------------------------
    | Register Controller
    |--------------------------------------------------------------------------
    |
    | This controller handles the registration of new users as well as their
    | validation and creation. By default this controller uses a trait to
    | provide this functionality without requiring any additional code.
    |
    */

    use RegistersUsers;

    /**
     * Where to redirect users after registration.
     *
     * @var string
     */
    protected $redirectTo = RouteServiceProvider::HOME;

    /**
     * Create a new controller instance.
     *
     * @return void
     */
    public function __construct()
    {
        $this->middleware('guest');
    }

    /**
     * Get a validator for an incoming registration request.
     *
     * @param  array  $data
     * @return \Illuminate\Contracts\Validation\Validator
     */
    protected function validator(array $data)
    {
        return Validator::make($data, [
            'name' => ['required', 'string', 'max:255'],
            'email' => ['required', 'string', 'email', 'max:255', 'unique:users'],
            'password' => ['required', 'string', 'min:8', 'required_with:password_confirmation', 'same:password_confirmation'],
            'password_confirmation' => 'min:8'
        ]);
    }

    /**
     * Create a new user instance after a valid registration.
     *
     * @param  array  $data
     * @return \App\User
     */
    protected function create(array $data)
    {
        if (User::count() === 0) {
            $roleId = 1;
        }

        User::create([
            'name' => $data['name'],
            'email' => $data['email'],
            'roleId' => $roleId,
            'password' => Hash::make($data['password']),
        ]);

        $user = User::OrderBy('created_at', 'desc')->first();
        $role_r = Role::where('id', '=', 1)->firstOrFail();
        $user->assignRole($role_r);

        return $user;
    }

    public function candidatRegister(Request $request)
    {
        $this->validate($request, [
            'candidatRegisterName' => 'required|max:120',
            'candidatRegisterEmail' => 'required|email|unique:users,email',
            'candidatRegisterPassword' => 'required|min:8|required_with:candidatRegisterPasswordConfirmation|same:candidatRegisterPasswordConfirmation',
            'candidatRegisterPasswordConfirmation' => 'required|min:8'
        ]);

        User::create([
            'name' => $request['candidatRegisterName'],
            'email' => $request['candidatRegisterEmail'],
            'roleId' => 2,
            'password' => Hash::make($request['candidatRegisterPassword']),
        ]);

        $user = User::OrderBy('created_at', 'desc')->first();

        $role_r = Role::where('id', '=', 2)->firstOrFail();
        $user->assignRole($role_r);

        return $user;
    }

    public function entrepriseRegister(Request $request)
    {
        $this->validate($request, [
            'epriseRegisterSR' => 'required|max:120',
            'epriseRegisterEmail' => 'required|email|unique:users,email',
            'epriseRegisterPassword' => 'required|min:8|required_with:epriseRegisterPasswordConfirmation|same:epriseRegisterPasswordConfirmation',
            'epriseRegisterPasswordConfirmation' => 'required|min:8'
        ]);

        User::create([
            'name' => $request['epriseRegisterSR'],
            'email' => $request['epriseRegisterEmail'],
            'roleId' => 3,
            'password' => Hash::make($request['epriseRegisterPassword']),
        ]);

        $user = User::OrderBy('created_at', 'desc')->first();

        $role_r = Role::where('id', '=', 3)->firstOrFail();
        $user->assignRole($role_r);

        return $user;
    }
}
